@@ -7,6 +7,8 @@ import time
 from whatap import build
 from whatap.util.date_util import DateUtil
 import threading
+import builtins
+import configparser
 
 __version__ = build.version
 
@@ -47,6 +49,38 @@ LOG_FILE_NAME = 'whatap-hook.log'
 
 isFrappeCommands = "get-frappe-commands" in sys.argv if hasattr(sys, "argv") else False
 
+temporary_config = configparser.ConfigParser()
+
+try:
+    if os.path.exists('whatap.conf'):
+        with open('whatap.conf') as f:
+            file_content = f.read()
+        temporary_file_content = '[dummy_section]\n' + file_content
+        temporary_config.read_string(temporary_file_content)
+        console_option = temporary_config.get('dummy_section', 'ignore_whatap_stdout', fallback='false')
+    else:
+        console_option = 'false'
+except Exception as e:
+    print('WHATAP : WHATAP.CONF READ ERROR')
+
+
+
+original_print = builtins.print
+
+def print_option(func):
+    def wrapper(*args, **kwargs):
+
+        if(console_option == 'false'):
+            result = func(*args, **kwargs)
+        else:
+            result = None
+        return result
+    return wrapper
+
+__builtins__ = dict(__builtins__)
+__builtins__['print'] = print_option(original_print)
+
+
 def whatap_print(*args):
     if isFrappeCommands:
         logging.info(*args)
