@@ -28,6 +28,23 @@ _RESPONSE='response'
 _REMOTE_ADDR='remoteAddr'
 _COOKIE='cookie'
 
+async def sse_body_wrapper(original_iterator, ctx,environ, response):
+    try:
+        async for chunk in original_iterator:
+            yield chunk
+    except Exception as e:
+        interceptor_step_error(e)
+        raise
+    finally:
+        if ctx:
+            if conf.profile_http_header_enabled:
+                sendHeaders(ctx, environ)
+            if response and conf.trace_user_enabled:
+                if not conf.trace_user_using_ip:
+                    setUserId(environ, response, ctx._rawuserid)
+            end_interceptor(ctx=ctx)
+
+
 def getUserId(headers,  defValue):
     try:
         if conf.user_header_ticket:
@@ -36,7 +53,7 @@ def getUserId(headers,  defValue):
                 return hash_util.hashFromString(ticket), ticket
             return 0,""
         cookie = headers.get("cookie")
-        
+
         if cookie:
             if len(cookie) >= conf.trace_user_cookie_limit :
                 return defValue
@@ -74,12 +91,12 @@ def sendHeaders(ctx, environ):
     for key, value in environ.items():
         keys.append(key)
     keys.sort()
-    
+
     text = ''
     for key in keys:
         text += '{}={}\n'.format(key,
                                 environ[key])
-    
+
     datas = ['HTTP-HEADERS', 'HTTP-HEADERS', text]
     ctx.start_time = DateUtil.nowSystem()
     async_sender.send_packet(PacketTypeEnum.TX_MSG, ctx, datas)
@@ -88,7 +105,7 @@ def setUserId(environ, res, cookieValue):
     try:
         if not conf.user_header_ticket:
             cookie = environ.get(_COOKIE)
-            
+
             if not cookie or cookie.find(userid_util.WHATAP_R) < 0 or cookie.find(cookieValue) < 0:
                 res.set_cookie(key=userid_util.WHATAP_R, value=cookieValue, \
                     max_age=bit_util.INT_MAX_VALUE, path="/", \
@@ -118,7 +135,7 @@ def interceptor_error_log(trxid, e, fn, args, kwargs):
         lastlineno = lineno
         lastf_globals = fr.f_globals
 
-    fields = {'errorClass': errorClass, 
+    fields = {'errorClass': errorClass,
                   'args': str(inspect.getcallargs(fn, *args, **kwargs))}
     if lastfilename and lastlineno:
         fields['filename'] = lastfilename
@@ -133,7 +150,7 @@ def interceptor_error_log(trxid, e, fn, args, kwargs):
                 error += ''.join([indicator, l.lstrip()])
             else:
                 error += l
-    
+
     p = logSinkPack.getLogSinkPack(
         t = DateUtil.now(),
         category = "UnhandledException",
@@ -146,7 +163,7 @@ def interceptor_error_log(trxid, e, fn, args, kwargs):
     bout = whatapio.DataOutputX()
     bout.writePack(p, None)
     packbytes = bout.toByteArray()
-    
+
     async_sender.send_relaypack(packbytes)
 
 def interceptor(fn, dependant, *args, **kwargs):
@@ -158,7 +175,7 @@ def interceptor(fn, dependant, *args, **kwargs):
     environ = whatap_dict.get('headers')
     ctx.host = environ.get('host')
     ctx.service_name = dependant.path
-    
+
     ctx.remoteIp = getRemoteAddr(environ, whatap_dict)
 
     ctx.userAgentString = environ.get('user_agent')
@@ -172,7 +189,7 @@ def interceptor(fn, dependant, *args, **kwargs):
 
     mstt = environ.get('{}'.format(
         conf._trace_mtrace_caller_key), '')
-    
+
     if mstt:
         ctx.setTransfer(mstt)
         if conf.stat_mtrace_enabled:
@@ -188,7 +205,7 @@ def interceptor(fn, dependant, *args, **kwargs):
             ctx.setTxid(myid)
     caller_poid = environ.get('{}'.format(
         conf._trace_mtrace_caller_poid_key), '')
-    
+
     if caller_poid:
         ctx.mcaller_poid = caller_poid
 
@@ -200,7 +217,7 @@ def interceptor(fn, dependant, *args, **kwargs):
         pass
 
     start_interceptor(ctx)
-    
+
     try:
         callback = fn(*args, **kwargs)
         ctx = TraceContextManager.getLocalContext()
@@ -219,7 +236,7 @@ def interceptor(fn, dependant, *args, **kwargs):
                 if hasattr(callback, 'reason_phrase'):
                     errors.insert(0, callback.reason_phrase)
                 interceptor_error(status_code, errors)
-                
+
             return callback
     except Exception as e:
         interceptor_step_error(e)
@@ -230,7 +247,7 @@ def interceptor(fn, dependant, *args, **kwargs):
             if conf.profile_http_header_enabled:
                 sendHeaders(ctx, environ)
             response = whatap_dict.get(_RESPONSE)
-            
+
             if response and conf.trace_user_enabled:
                 if not conf.trace_user_using_ip:
                     setUserId(environ, response, ctx._rawuserid )
@@ -241,11 +258,11 @@ def interceptor(fn, dependant, *args, **kwargs):
 async def interceptor_async(fn, dependant, *args, **kwargs):
     if not hasattr(dependant, _WHATAP_DICT):
         return await fn(*args, **kwargs)
-    
+
     ctx = TraceContextManager.getLocalContext()
-    
+
     ctx.service_name = dependant.path
-    
+
     whatap_dict = getattr(dependant, _WHATAP_DICT)
     environ = whatap_dict.get('headers')
     ctx.host = environ.get('host')
@@ -262,7 +279,7 @@ async def interceptor_async(fn, dependant, *args, **kwargs):
 
     mstt = environ.get('{}'.format(
         conf._trace_mtrace_caller_key), '')
-    
+
     if mstt:
         ctx.setTransfer(mstt)
         if conf.stat_mtrace_enabled:
@@ -278,7 +295,7 @@ async def interceptor_async(fn, dependant, *args, **kwargs):
             ctx.setTxid(myid)
     caller_poid = environ.get('{}'.format(
         conf._trace_mtrace_caller_poid_key), '')
-    
+
     if caller_poid:
         ctx.mcaller_poid = caller_poid
 
@@ -288,12 +305,19 @@ async def interceptor_async(fn, dependant, *args, **kwargs):
             return await fn(*args, **kwargs)
     except Exception as e:
         pass
-    
+
     start_interceptor(ctx)
-    
+    callback = None
+
     try:
         callback = await fn(*args, **kwargs)
+        from fastapi.responses import StreamingResponse
         ctx = TraceContextManager.getLocalContext()
+
+        if isinstance(callback, StreamingResponse) and hasattr(callback, "body_iterator"):
+            original_iter = callback.body_iterator
+            callback.body_iterator = sse_body_wrapper(original_iter, ctx, environ,whatap_dict.get(_RESPONSE))
+
         if ctx:
             query_string = "&".join([str(query) for query in dependant.query_params])
             if query_string:
@@ -309,7 +333,7 @@ async def interceptor_async(fn, dependant, *args, **kwargs):
                 if hasattr(callback, 'reason_phrase'):
                     errors.insert(0, callback.reason_phrase)
                 interceptor_error(status_code, errors)
-            
+
             return callback
     except Exception as e:
         interceptor_step_error(e)
@@ -317,7 +341,7 @@ async def interceptor_async(fn, dependant, *args, **kwargs):
         raise e
     finally:
         ctx = TraceContextManager.getLocalContext()
-        if ctx:
+        if ctx and not isinstance(callback, StreamingResponse):
             if conf.profile_http_header_enabled:
                 sendHeaders(ctx, environ)
             response = whatap_dict.get(_RESPONSE)
